@@ -14,12 +14,13 @@
 //! (commonly referred to as Data Definition Language, or DDL)
 
 #[cfg(not(feature = "std"))]
-use alloc::{boxed::Box, string::ToString, vec::Vec};
+use alloc::{boxed::Box, string::String, string::ToString, vec::Vec};
 use core::fmt;
 
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
 
+use crate::ast::value::escape_single_quote_string;
 use crate::ast::{display_comma_separated, display_separated, DataType, Expr, Ident, ObjectName};
 use crate::tokenizer::Token;
 
@@ -31,8 +32,12 @@ pub enum AlterTableOperation {
     AddConstraint(TableConstraint),
     /// `ADD [ COLUMN ] <column_def>`
     AddColumn { column_def: ColumnDef },
-    /// TODO: implement `DROP CONSTRAINT <name>`
-    DropConstraint { name: Ident },
+    /// `DROP CONSTRAINT [ IF EXISTS ] <name>`
+    DropConstraint {
+        if_exists: bool,
+        name: Ident,
+        cascade: bool,
+    },
     /// `DROP [ COLUMN ] [ IF EXISTS ] <column_name> [ CASCADE ]`
     DropColumn {
         column_name: Ident,
@@ -67,6 +72,15 @@ pub enum AlterTableOperation {
         data_type: DataType,
         options: Vec<ColumnOption>,
     },
+    /// `RENAME CONSTRAINT <old_constraint_name> TO <new_constraint_name>`
+    ///
+    /// Note: this is a PostgreSQL-specific operation.
+    RenameConstraint { old_name: Ident, new_name: Ident },
+    /// `ALTER [ COLUMN ]`
+    AlterColumn {
+        column_name: Ident,
+        op: AlterColumnOperation,
+    },
 }
 
 impl fmt::Display for AlterTableOperation {
@@ -83,7 +97,10 @@ impl fmt::Display for AlterTableOperation {
             ),
             AlterTableOperation::AddConstraint(c) => write!(f, "ADD {}", c),
             AlterTableOperation::AddColumn { column_def } => {
-                write!(f, "ADD COLUMN {}", column_def.to_string())
+                write!(f, "ADD COLUMN {}", column_def)
+            }
+            AlterTableOperation::AlterColumn { column_name, op } => {
+                write!(f, "ALTER COLUMN {} {}", column_name, op)
             }
             AlterTableOperation::DropPartitions {
                 partitions,
@@ -94,7 +111,19 @@ impl fmt::Display for AlterTableOperation {
                 display_comma_separated(partitions),
                 ie = if *if_exists { " IF EXISTS" } else { "" }
             ),
-            AlterTableOperation::DropConstraint { name } => write!(f, "DROP CONSTRAINT {}", name),
+            AlterTableOperation::DropConstraint {
+                if_exists,
+                name,
+                cascade,
+            } => {
+                write!(
+                    f,
+                    "DROP CONSTRAINT {}{}{}",
+                    if *if_exists { "IF EXISTS " } else { "" },
+                    name,
+                    if *cascade { " CASCADE" } else { "" },
+                )
+            }
             AlterTableOperation::DropColumn {
                 column_name,
                 if_exists,
@@ -139,6 +168,51 @@ impl fmt::Display for AlterTableOperation {
                     write!(f, " {}", display_separated(options, " "))
                 }
             }
+            AlterTableOperation::RenameConstraint { old_name, new_name } => {
+                write!(f, "RENAME CONSTRAINT {} TO {}", old_name, new_name)
+            }
+        }
+    }
+}
+
+/// An `ALTER COLUMN` (`Statement::AlterTable`) operation
+#[derive(Debug, Clone, PartialEq, Eq, Hash)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+pub enum AlterColumnOperation {
+    /// `SET NOT NULL`
+    SetNotNull,
+    /// `DROP NOT NULL`
+    DropNotNull,
+    /// `SET DEFAULT <expr>`
+    SetDefault { value: Expr },
+    /// `DROP DEFAULT`
+    DropDefault,
+    /// `[SET DATA] TYPE <data_type> [USING <expr>]`
+    SetDataType {
+        data_type: DataType,
+        /// PostgreSQL specific
+        using: Option<Expr>,
+    },
+}
+
+impl fmt::Display for AlterColumnOperation {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        match self {
+            AlterColumnOperation::SetNotNull => write!(f, "SET NOT NULL",),
+            AlterColumnOperation::DropNotNull => write!(f, "DROP NOT NULL",),
+            AlterColumnOperation::SetDefault { value } => {
+                write!(f, "SET DEFAULT {}", value)
+            }
+            AlterColumnOperation::DropDefault {} => {
+                write!(f, "DROP DEFAULT")
+            }
+            AlterColumnOperation::SetDataType { data_type, using } => {
+                if let Some(expr) = using {
+                    write!(f, "SET DATA TYPE {} USING {}", data_type, expr)
+                } else {
+                    write!(f, "SET DATA TYPE {}", data_type)
+                }
+            }
         }
     }
 }
@@ -281,7 +355,9 @@ pub enum ColumnOption {
     /// `DEFAULT <restricted-expr>`
     Default(Expr),
     /// `{ PRIMARY KEY | UNIQUE }`
-    Unique { is_primary: bool },
+    Unique {
+        is_primary: bool,
+    },
     /// A referential integrity constraint (`[FOREIGN KEY REFERENCES
     /// <foreign_table> (<referred_columns>)
     /// { [ON DELETE <referential_action>] [ON UPDATE <referential_action>] |
@@ -299,6 +375,8 @@ pub enum ColumnOption {
     /// - MySQL's `AUTO_INCREMENT` or SQLite's `AUTOINCREMENT`
     /// - ...
     DialectSpecific(Vec<Token>),
+    CharacterSet(ObjectName),
+    Comment(String),
 }
 
 impl fmt::Display for ColumnOption {
@@ -331,6 +409,8 @@ impl fmt::Display for ColumnOption {
             }
             Check(expr) => write!(f, "CHECK ({})", expr),
             DialectSpecific(val) => write!(f, "{}", display_separated(val, " ")),
+            CharacterSet(n) => write!(f, "CHARACTER SET {}", n),
+            Comment(v) => write!(f, "COMMENT '{}'", escape_single_quote_string(v)),
         }
     }
 }
