@@ -36,8 +36,8 @@ pub use self::ddl::{
 pub use self::operator::{BinaryOperator, UnaryOperator};
 pub use self::query::{
     Cte, Fetch, Join, JoinConstraint, JoinOperator, LateralView, LockType, Offset, OffsetRows,
-    OrderByExpr, Query, Select, SelectItem, SetExpr, SetOperator, TableAlias, TableFactor,
-    TableWithJoins, Top, Values, With,
+    OrderByExpr, Query, Select, SelectInto, SelectItem, SetExpr, SetOperator, TableAlias,
+    TableFactor, TableWithJoins, Top, Values, With,
 };
 pub use self::value::{DateTimeField, TrimWhereField, Value};
 
@@ -741,14 +741,16 @@ pub enum Statement {
         table_name: ObjectName,
         /// COLUMNS
         columns: Vec<Ident>,
+        /// If true, is a 'COPY TO' statement. If false is a 'COPY FROM'
+        to: bool,
+        /// The source of 'COPY FROM', or the target of 'COPY TO'
+        target: CopyTarget,
+        /// WITH options (from PostgreSQL version 9.0)
+        options: Vec<CopyOption>,
+        /// WITH options (before PostgreSQL version 9.0)
+        legacy_options: Vec<CopyLegacyOption>,
         /// VALUES a vector of values to be copied
         values: Vec<Option<String>>,
-        /// file name of the data to be copied from
-        filename: Option<Ident>,
-        /// delimiter character
-        delimiter: Option<Ident>,
-        /// CSV HEADER
-        csv_header: bool,
     },
     /// UPDATE
     Update {
@@ -756,6 +758,8 @@ pub enum Statement {
         table: TableWithJoins,
         /// Column assignments
         assignments: Vec<Assignment>,
+        /// Table which provide value to be set
+        from: Option<TableWithJoins>,
         /// WHERE
         selection: Option<Expr>,
     },
@@ -956,6 +960,21 @@ pub enum Statement {
         /// A SQL query that specifies what to explain
         statement: Box<Statement>,
     },
+    /// SAVEPOINT -- define a new savepoint within the current transaction
+    Savepoint { name: Ident },
+    // MERGE INTO statement, based on Snowflake. See <https://docs.snowflake.com/en/sql-reference/sql/merge.html>
+    Merge {
+        // Specifies the table to merge
+        table: TableFactor,
+        // Specifies the table or subquery to join with the target table
+        source: Box<SetExpr>,
+        // Specifies alias to the table that is joined with target table
+        alias: Option<TableAlias>,
+        // Specifies the expression on which to join the target table and source
+        on: Box<Expr>,
+        // Specifies the actions to perform when values match or do not match.
+        clauses: Vec<MergeClause>,
+    },
 }
 
 impl fmt::Display for Statement {
@@ -1124,30 +1143,25 @@ impl fmt::Display for Statement {
             Statement::Copy {
                 table_name,
                 columns,
+                to,
+                target,
+                options,
+                legacy_options,
                 values,
-                delimiter,
-                filename,
-                csv_header,
             } => {
                 write!(f, "COPY {}", table_name)?;
                 if !columns.is_empty() {
                     write!(f, " ({})", display_comma_separated(columns))?;
                 }
-
-                if let Some(name) = filename {
-                    write!(f, " FROM {}", name)?;
-                } else {
-                    write!(f, " FROM stdin ")?;
+                write!(f, " {} {}", if *to { "TO" } else { "FROM" }, target)?;
+                if !options.is_empty() {
+                    write!(f, " ({})", display_comma_separated(options))?;
                 }
-                if let Some(delimiter) = delimiter {
-                    write!(f, " DELIMITER {}", delimiter)?;
-                }
-                if *csv_header {
-                    write!(f, " CSV HEADER")?;
+                if !legacy_options.is_empty() {
+                    write!(f, " {}", display_separated(legacy_options, " "))?;
                 }
                 if !values.is_empty() {
-                    write!(f, ";")?;
-                    writeln!(f)?;
+                    writeln!(f, ";")?;
                     let mut delim = "";
                     for v in values {
                         write!(f, "{}", delim)?;
@@ -1158,8 +1172,6 @@ impl fmt::Display for Statement {
                             write!(f, "\\N")?;
                         }
                     }
-                }
-                if filename.is_none() {
                     write!(f, "\n\\.")?;
                 }
                 Ok(())
@@ -1167,12 +1179,16 @@ impl fmt::Display for Statement {
             Statement::Update {
                 table,
                 assignments,
+                from,
                 selection,
             } => {
                 write!(f, "UPDATE {}", table)?;
                 if !assignments.is_empty() {
                     write!(f, " SET {}", display_comma_separated(assignments))?;
                 }
+                if let Some(from) = from {
+                    write!(f, " FROM {}", from)?;
+                }
                 if let Some(selection) = selection {
                     write!(f, " WHERE {}", selection)?;
                 }
@@ -1194,7 +1210,7 @@ impl fmt::Display for Statement {
                 location,
                 managed_location,
             } => {
-                write!(f, "CREATE")?;
+                write!(f, "CREATE DATABASE")?;
                 if *if_not_exists {
                     write!(f, " IF NOT EXISTS")?;
                 }
@@ -1606,6 +1622,24 @@ impl fmt::Display for Statement {
                     write!(f, "NULL")
                 }
             }
+            Statement::Savepoint { name } => {
+                write!(f, "SAVEPOINT ")?;
+                write!(f, "{}", name)
+            }
+            Statement::Merge {
+                table,
+                source,
+                alias,
+                on,
+                clauses,
+            } => {
+                write!(f, "MERGE INTO {} USING {} ", table, source)?;
+                if let Some(a) = alias {
+                    write!(f, "as {} ", a)?;
+                };
+                write!(f, "ON {} ", on)?;
+                write!(f, "{}", display_separated(clauses, " "))
+            }
         }
     }
 }
@@ -2137,6 +2171,213 @@ impl fmt::Display for SqliteOnConflict {
     }
 }
 
+#[derive(Debug, Clone, PartialEq, Eq, Hash)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+pub enum CopyTarget {
+    Stdin,
+    Stdout,
+    File {
+        /// The path name of the input or output file.
+        filename: String,
+    },
+    Program {
+        /// A command to execute
+        command: String,
+    },
+}
+
+impl fmt::Display for CopyTarget {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        use CopyTarget::*;
+        match self {
+            Stdin { .. } => write!(f, "STDIN"),
+            Stdout => write!(f, "STDOUT"),
+            File { filename } => write!(f, "'{}'", value::escape_single_quote_string(filename)),
+            Program { command } => write!(
+                f,
+                "PROGRAM '{}'",
+                value::escape_single_quote_string(command)
+            ),
+        }
+    }
+}
+
+/// An option in `COPY` statement.
+///
+/// <https://www.postgresql.org/docs/14/sql-copy.html>
+#[derive(Debug, Clone, PartialEq, Eq, Hash)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+pub enum CopyOption {
+    /// FORMAT format_name
+    Format(Ident),
+    /// FREEZE \[ boolean \]
+    Freeze(bool),
+    /// DELIMITER 'delimiter_character'
+    Delimiter(char),
+    /// NULL 'null_string'
+    Null(String),
+    /// HEADER \[ boolean \]
+    Header(bool),
+    /// QUOTE 'quote_character'
+    Quote(char),
+    /// ESCAPE 'escape_character'
+    Escape(char),
+    /// FORCE_QUOTE { ( column_name [, ...] ) | * }
+    ForceQuote(Vec<Ident>),
+    /// FORCE_NOT_NULL ( column_name [, ...] )
+    ForceNotNull(Vec<Ident>),
+    /// FORCE_NULL ( column_name [, ...] )
+    ForceNull(Vec<Ident>),
+    /// ENCODING 'encoding_name'
+    Encoding(String),
+}
+
+impl fmt::Display for CopyOption {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        use CopyOption::*;
+        match self {
+            Format(name) => write!(f, "FORMAT {}", name),
+            Freeze(true) => write!(f, "FREEZE"),
+            Freeze(false) => write!(f, "FREEZE FALSE"),
+            Delimiter(char) => write!(f, "DELIMITER '{}'", char),
+            Null(string) => write!(f, "NULL '{}'", value::escape_single_quote_string(string)),
+            Header(true) => write!(f, "HEADER"),
+            Header(false) => write!(f, "HEADER FALSE"),
+            Quote(char) => write!(f, "QUOTE '{}'", char),
+            Escape(char) => write!(f, "ESCAPE '{}'", char),
+            ForceQuote(columns) => write!(f, "FORCE_QUOTE ({})", display_comma_separated(columns)),
+            ForceNotNull(columns) => {
+                write!(f, "FORCE_NOT_NULL ({})", display_comma_separated(columns))
+            }
+            ForceNull(columns) => write!(f, "FORCE_NULL ({})", display_comma_separated(columns)),
+            Encoding(name) => write!(f, "ENCODING '{}'", value::escape_single_quote_string(name)),
+        }
+    }
+}
+
+/// An option in `COPY` statement before PostgreSQL version 9.0.
+///
+/// <https://www.postgresql.org/docs/8.4/sql-copy.html>
+#[derive(Debug, Clone, PartialEq, Eq, Hash)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+pub enum CopyLegacyOption {
+    /// BINARY
+    Binary,
+    /// DELIMITER \[ AS \] 'delimiter_character'
+    Delimiter(char),
+    /// NULL \[ AS \] 'null_string'
+    Null(String),
+    /// CSV ...
+    Csv(Vec<CopyLegacyCsvOption>),
+}
+
+impl fmt::Display for CopyLegacyOption {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        use CopyLegacyOption::*;
+        match self {
+            Binary => write!(f, "BINARY"),
+            Delimiter(char) => write!(f, "DELIMITER '{}'", char),
+            Null(string) => write!(f, "NULL '{}'", value::escape_single_quote_string(string)),
+            Csv(opts) => write!(f, "CSV {}", display_separated(opts, " ")),
+        }
+    }
+}
+
+/// A `CSV` option in `COPY` statement before PostgreSQL version 9.0.
+///
+/// <https://www.postgresql.org/docs/8.4/sql-copy.html>
+#[derive(Debug, Clone, PartialEq, Eq, Hash)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+pub enum CopyLegacyCsvOption {
+    /// HEADER
+    Header,
+    /// QUOTE \[ AS \] 'quote_character'
+    Quote(char),
+    /// ESCAPE \[ AS \] 'escape_character'
+    Escape(char),
+    /// FORCE QUOTE { column_name [, ...] | * }
+    ForceQuote(Vec<Ident>),
+    /// FORCE NOT NULL column_name [, ...]
+    ForceNotNull(Vec<Ident>),
+}
+
+impl fmt::Display for CopyLegacyCsvOption {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        use CopyLegacyCsvOption::*;
+        match self {
+            Header => write!(f, "HEADER"),
+            Quote(char) => write!(f, "QUOTE '{}'", char),
+            Escape(char) => write!(f, "ESCAPE '{}'", char),
+            ForceQuote(columns) => write!(f, "FORCE QUOTE {}", display_comma_separated(columns)),
+            ForceNotNull(columns) => {
+                write!(f, "FORCE NOT NULL {}", display_comma_separated(columns))
+            }
+        }
+    }
+}
+
+///  
+#[derive(Debug, Clone, PartialEq, Eq, Hash)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+pub enum MergeClause {
+    MatchedUpdate {
+        predicate: Option<Expr>,
+        assignments: Vec<Assignment>,
+    },
+    MatchedDelete(Option<Expr>),
+    NotMatched {
+        predicate: Option<Expr>,
+        columns: Vec<Ident>,
+        values: Values,
+    },
+}
+
+impl fmt::Display for MergeClause {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        use MergeClause::*;
+        write!(f, "WHEN")?;
+        match self {
+            MatchedUpdate {
+                predicate,
+                assignments,
+            } => {
+                write!(f, " MATCHED")?;
+                if let Some(pred) = predicate {
+                    write!(f, " AND {}", pred)?;
+                }
+                write!(
+                    f,
+                    " THEN UPDATE SET {}",
+                    display_comma_separated(assignments)
+                )
+            }
+            MatchedDelete(predicate) => {
+                write!(f, " MATCHED")?;
+                if let Some(pred) = predicate {
+                    write!(f, " AND {}", pred)?;
+                }
+                write!(f, " THEN DELETE")
+            }
+            NotMatched {
+                predicate,
+                columns,
+                values,
+            } => {
+                write!(f, " NOT MATCHED")?;
+                if let Some(pred) = predicate {
+                    write!(f, " AND {}", pred)?;
+                }
+                write!(
+                    f,
+                    " THEN INSERT ({}) {}",
+                    display_comma_separated(columns),
+                    values
+                )
+            }
+        }
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
