@@ -10,9 +10,10 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
+use core::fmt;
+
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
-use std::fmt;
 
 /// Unary operators
 #[derive(Debug, Clone, PartialEq, Eq, Hash)]
@@ -59,7 +60,7 @@ pub enum BinaryOperator {
     Minus,
     Multiply,
     Divide,
-    Modulus,
+    Modulo,
     StringConcat,
     Gt,
     Lt,
@@ -70,14 +71,21 @@ pub enum BinaryOperator {
     NotEq,
     And,
     Or,
+    Xor,
     Like,
     NotLike,
+    ILike,
+    NotILike,
     BitwiseOr,
     BitwiseAnd,
     BitwiseXor,
     PGBitwiseXor,
     PGBitwiseShiftLeft,
     PGBitwiseShiftRight,
+    PGRegexMatch,
+    PGRegexIMatch,
+    PGRegexNotMatch,
+    PGRegexNotIMatch,
 }
 
 impl fmt::Display for BinaryOperator {
@@ -87,7 +95,7 @@ impl fmt::Display for BinaryOperator {
             BinaryOperator::Minus => "-",
             BinaryOperator::Multiply => "*",
             BinaryOperator::Divide => "/",
-            BinaryOperator::Modulus => "%",
+            BinaryOperator::Modulo => "%",
             BinaryOperator::StringConcat => "||",
             BinaryOperator::Gt => ">",
             BinaryOperator::Lt => "<",
@@ -98,14 +106,21 @@ impl fmt::Display for BinaryOperator {
             BinaryOperator::NotEq => "<>",
             BinaryOperator::And => "AND",
             BinaryOperator::Or => "OR",
+            BinaryOperator::Xor => "XOR",
             BinaryOperator::Like => "LIKE",
             BinaryOperator::NotLike => "NOT LIKE",
+            BinaryOperator::ILike => "ILIKE",
+            BinaryOperator::NotILike => "NOT ILIKE",
             BinaryOperator::BitwiseOr => "|",
             BinaryOperator::BitwiseAnd => "&",
             BinaryOperator::BitwiseXor => "^",
             BinaryOperator::PGBitwiseXor => "#",
             BinaryOperator::PGBitwiseShiftLeft => "<<",
             BinaryOperator::PGBitwiseShiftRight => ">>",
+            BinaryOperator::PGRegexMatch => "~",
+            BinaryOperator::PGRegexIMatch => "~*",
+            BinaryOperator::PGRegexNotMatch => "!~",
+            BinaryOperator::PGRegexNotIMatch => "!~*",
         })
     }
 }
