@@ -20,15 +20,15 @@ impl Dialect for MySqlDialect {
         // See https://dev.mysql.com/doc/refman/8.0/en/identifiers.html.
         // We don't yet support identifiers beginning with numbers, as that
         // makes it hard to distinguish numeric literals.
-        (ch >= 'a' && ch <= 'z')
-            || (ch >= 'A' && ch <= 'Z')
+        ('a'..='z').contains(&ch)
+            || ('A'..='Z').contains(&ch)
             || ch == '_'
             || ch == '$'
-            || (ch >= '\u{0080}' && ch <= '\u{ffff}')
+            || ('\u{0080}'..='\u{ffff}').contains(&ch)
     }
 
     fn is_identifier_part(&self, ch: char) -> bool {
-        self.is_identifier_start(ch) || (ch >= '0' && ch <= '9')
+        self.is_identifier_start(ch) || ('0'..='9').contains(&ch)
     }
 
     fn is_delimited_identifier_start(&self, ch: char) -> bool {
