@@ -195,6 +195,7 @@ define_keywords!(
     EACH,
     ELEMENT,
     ELSE,
+    ENCODING,
     END,
     END_EXEC = "END-EXEC",
     END_FRAME,
@@ -227,10 +228,15 @@ define_keywords!(
     FLOOR,
     FOLLOWING,
     FOR,
+    FORCE,
+    FORCE_NOT_NULL,
+    FORCE_NULL,
+    FORCE_QUOTE,
     FOREIGN,
     FORMAT,
     FRAME_ROW,
     FREE,
+    FREEZE,
     FROM,
     FULL,
     FUNCTION,
@@ -295,6 +301,7 @@ define_keywords!(
     LOWER,
     MANAGEDLOCATION,
     MATCH,
+    MATCHED,
     MATERIALIZED,
     MAX,
     MEMBER,
@@ -371,8 +378,10 @@ define_keywords!(
     PRIMARY,
     PRIVILEGES,
     PROCEDURE,
+    PROGRAM,
     PURGE,
     QUARTER,
+    QUOTE,
     RANGE,
     RANK,
     RCFILE,
@@ -448,6 +457,7 @@ define_keywords!(
     STDDEV_POP,
     STDDEV_SAMP,
     STDIN,
+    STDOUT,
     STORED,
     STRING,
     SUBMULTISET,
@@ -498,6 +508,7 @@ define_keywords!(
     UNION,
     UNIQUE,
     UNKNOWN,
+    UNLOGGED,
     UNNEST,
     UNSIGNED,
     UPDATE,
@@ -518,6 +529,7 @@ define_keywords!(
     VERSIONING,
     VIEW,
     VIRTUAL,
+    WEEK,
     WHEN,
     WHENEVER,
     WHERE,
@@ -598,4 +610,5 @@ pub const RESERVED_FOR_COLUMN_ALIAS: &[Keyword] = &[
     Keyword::DISTRIBUTE,
     // Reserved only as a column alias in the `SELECT` clause
     Keyword::FROM,
+    Keyword::INTO,
 ];
